package de.intevation.flys.client.server;

import org.w3c.dom.Document;

import com.google.gwt.user.server.rpc.RemoteServiceServlet;

import de.intevation.artifacts.common.utils.ClientProtocolUtils;

import de.intevation.artifacts.httpclient.exceptions.ConnectionException;
import de.intevation.artifacts.httpclient.http.HttpClient;
import de.intevation.artifacts.httpclient.http.HttpClientImpl;
import de.intevation.artifacts.httpclient.http.response.DocumentResponseHandler;

import de.intevation.flys.client.shared.exceptions.ServerException;
import de.intevation.flys.client.shared.model.Collection;

import de.intevation.flys.client.client.services.DescribeCollectionService;


/**
 * This service implements a method that queries the DESCRIBE document of a
 * specific collection and returns a Collection object with the information of
 * the document.
 *
 * @author <a href="mailto:ingo.weinzierl@intevation.de">Ingo Weinzierl</a>
 */
public class DescribeCollectionServiceImpl
extends      RemoteServiceServlet
implements   DescribeCollectionService
{
    /** The error message key that is thrown if an error occured while
     * describe() a Collection.*/
    public static final String ERROR_DESCRIBE_COLLECTION =
        "error_describe_collection";


    public Collection describe(String uuid, String serverUrl, String locale)
    throws ServerException
    {
        System.out.println("DescribeCollectionServiceImpl.describe");

        Document describe = ClientProtocolUtils.newDescribeCollectionDocument(
            uuid);

        HttpClient client = new HttpClientImpl(serverUrl, locale);

        try {
            Document response = (Document) client.doCollectionAction(
                describe, uuid, new DocumentResponseHandler());

            Collection c = CollectionHelper.parseCollection(response);

            if (c == null) {
                throw new ServerException(ERROR_DESCRIBE_COLLECTION);
            }

            System.out.println("Collection successfully parsed.");

            return c;
        }
        catch (ConnectionException ce) {
            System.err.println(ce.getLocalizedMessage());
        }

        throw new ServerException(ERROR_DESCRIBE_COLLECTION);
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
